=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2006-04-20 07:54:15 +0000
+++ bzrlib/errors.py	2006-04-21 05:52:44 +0000
@@ -894,3 +894,11 @@
 
 class BinaryFile(BzrNewError):
     """File is binary but should be text."""
+
+
+class IllegalPath(BzrNewError):
+    """The path %(path)s is not permitted on this platform"""
+
+    def __init__(self, path):
+        BzrNewError.__init__(self)
+        self.path = path

=== modified file 'bzrlib/tests/repository_implementations/test_fileid_involved.py'
--- bzrlib/tests/repository_implementations/test_fileid_involved.py	2006-04-12 04:57:34 +0000
+++ bzrlib/tests/repository_implementations/test_fileid_involved.py	2006-04-21 05:52:44 +0000
@@ -18,7 +18,9 @@
 
 from bzrlib.add import smart_add
 from bzrlib.builtins import merge
+from bzrlib.errors import IllegalPath
 from bzrlib.delta import compare_trees
+from bzrlib.tests import TestSkipped
 from bzrlib.tests.repository_implementations.test_repository import TestCaseWithRepository
 from bzrlib.workingtree import WorkingTree
 
@@ -62,7 +64,10 @@
         main_wt.add(['a', 'b', 'c'], ['a-file-id-2006-01-01-abcd',
                                  'b-file-id-2006-01-01-defg',
                                  'c-funky<file-id> quiji%bo'])
-        main_wt.commit("Commit one", rev_id="rev-A")
+        try:
+            main_wt.commit("Commit one", rev_id="rev-A")
+        except IllegalPath:
+            raise TestSkipped("File-id with <> not supported on this platform")
         #-------- end A -----------
 
         d1 = main_branch.bzrdir.clone('branch1')
@@ -187,7 +192,10 @@
         main_wt.add(['a', 'b', 'c'], ['a-file-id-2006-01-01-abcd',
                                  'b-file-id-2006-01-01-defg',
                                  'c-funky<file-id> quiji%bo'])
-        main_wt.commit("Commit one", rev_id="rev-A")
+        try:
+            main_wt.commit("Commit one", rev_id="rev-A")
+        except IllegalPath:
+            raise TestSkipped("Used unsupported characters")
 
         branch2_bzrdir = main_branch.bzrdir.sprout("branch2")
         branch2_branch = branch2_bzrdir.open_branch()

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2006-04-21 03:34:29 +0000
+++ bzrlib/transport/local.py	2006-04-21 05:52:44 +0000
@@ -25,6 +25,7 @@
 import tempfile
 import urllib
 
+from bzrlib.errors import IllegalPath
 from bzrlib.trace import mutter
 from bzrlib.transport import Transport, Server
 from bzrlib.osutils import abspath, realpath, normpath, pathjoin, rename
@@ -100,6 +101,8 @@
         path = relpath
         try:
             path = self.abspath(relpath)
+            if sys.platform=="win32" and ('<' in path or '>' in path) :
+                raise IllegalPath(path)
             fp = AtomicFile(path, 'wb', new_mode=mode)
         except (IOError, OSError),e:
             self._translate_error(e, path)

